@@ -1,7 +1,8 @@
+withr::local_options(list(tibble.width = Inf))
+
 test_that(
   desc = "one_sample_test parametric works",
   code = {
-    options(tibble.width = Inf)
     skip_if(getRversion() < "4.0")
 
     # parametric -------------------------------------------------
@@ -30,13 +31,12 @@ test_that(
       )
     )
 
-
     set.seed(123)
     expect_snapshot(select(df1, -expression))
-    expect_snapshot(df1$expression)
+    expect_snapshot(df1[["expression"]])
 
     expect_snapshot(select(df2, -expression))
-    expect_snapshot(df2$expression)
+    expect_snapshot(df2[["expression"]])
   }
 )
 
@@ -67,13 +67,12 @@ test_that(
       k = 4
     )
 
-
     set.seed(123)
     expect_snapshot(select(df1, -expression))
-    expect_snapshot(df1$expression)
+    expect_snapshot(df1[["expression"]])
 
     expect_snapshot(select(df2, -expression))
-    expect_snapshot(df2$expression)
+    expect_snapshot(df2[["expression"]])
   }
 )
 
@@ -109,10 +108,10 @@ test_that(
 
     set.seed(123)
     expect_snapshot(select(df1, -expression))
-    expect_snapshot(df1$expression)
+    expect_snapshot(df1[["expression"]])
 
     expect_snapshot(select(df2, -expression))
-    expect_snapshot(df2$expression)
+    expect_snapshot(df2[["expression"]])
   }
 )
 
@@ -152,7 +151,7 @@ test_that(
       conf.level = 0.90
     )
 
-    expect_snapshot(df1$expression)
+    expect_snapshot(df1[["expression"]])
 
     # extracting subtitle (with NA)
     set.seed(123)
@@ -167,6 +166,6 @@ test_that(
       conf.method = "eti"
     )
 
-    expect_snapshot(df2$expression)
+    expect_snapshot(df2[["expression"]])
   }
 )
