@@ -1,8 +1,10 @@
+withr::local_options(list(tibble.width = Inf))
+
 test_that(
   desc = " parametric t-tests",
   code = {
     skip_if(getRversion() < "4.0")
-    options(tibble.width = Inf)
+
 
     # one-sample t-test (with NAs) ---------
 
