@@ -2,14 +2,14 @@
 # Bayesian meta-analysis often crashes R session on macOS
 # this makes sure this test will be run after all others
 
+withr::local_options(list(tibble.width = Inf))
+
 test_that(
   desc = "meta_analysis works - bayesian",
   code = {
     skip_if_not_installed("metaBMA")
     skip_if(getRversion() < "4.0")
 
-    options(tibble.width = Inf)
-
     # setup
     set.seed(123)
 
@@ -49,6 +49,6 @@ test_that(
     expect_type(df, "list")
 
     expect_snapshot(dplyr::select(df, -expression))
-    expect_snapshot(df$expression)
+    expect_snapshot(df[["expression"]])
   }
 )
